@@ -234,7 +234,7 @@ class LocalPorvider(BaseProvider):
     def daily_index_industries_eod(self, instruments: list, fields: list, start_date: str = defualt_start_date,
                                    end_date: str = defualt_end_date):
         """ 
-            table_name: AIndexIndustry 
+            table_name: AIndexIndustriesEODCITICS 
             input:instruments:list,fields:list,start_date:str,end_date:str
             output: DataFrame
             fields: preclose open high low close change pctchange volume amount
@@ -244,7 +244,7 @@ class LocalPorvider(BaseProvider):
     def daily_aswsindex_eod(self, instruments: list, fields: list, start_date: str = defualt_start_date,
                             end_date: str = defualt_end_date):
         """ 
-            table_name: 'AIndexIndustriesEODCITICS'
+            table_name: 'ASWSIndexEOD'
             input:instruments:list,fields:list,start_date:str,end_date:str
             output: DataFrame
             fields: preclose open high low close change pctchange volume amount
@@ -254,7 +254,7 @@ class LocalPorvider(BaseProvider):
     def daily_cmfidxeod(self, instruments: list, fields: list, start_date: str = defualt_start_date,
                         end_date: str = defualt_end_date):
         """ 
-            table_name: 'AIndexIndustriesEODCITICS'
+            table_name: 'CMFIndexEOD'
             input:instruments:list,fields:list,start_date:str,end_date:str
             output: DataFrame
             fields: preclose open high low close change pctchange volume amount
@@ -341,6 +341,16 @@ class LocalPorvider(BaseProvider):
         """
         return TDP.get_daily_shsz_stkholding(instruments, fields, start_date, end_date)
 
+    def daily_shszchholdings(self, instruments: list, fields: list, start_date: str = defualt_start_date,
+                              end_date: str = defualt_end_date):
+        """
+            table_name: 'SHSCChannelholdings'
+            input: instruments,start_date,end_date
+            output: DataFrame
+            fields: return
+        """
+        return TDP.daily_shszchholdings(instruments, fields, start_date, end_date)
+
     def daily_indexweight(self, instruments, **kws):
         """
             table_name: 'AIndexFreeWeight'
@@ -612,6 +622,16 @@ class LocalPorvider(BaseProvider):
             fields : ...
         """
         return FRP.repo_fanc_indicator(instruments, fields, **kws)
+    
+    def repo_ashare_dividend(self,instruments,fields,**kws):
+        """
+            table_name: 'AShareDividend'
+            input:instruments:List(str),fields:List(str)
+                  optional: start_date:str,end_date:str,by [ann_date,reports_period]
+            output: DataFrame
+            fields : ...
+        """
+        return FRP.repo_ashare_dividend(instruments, fields, **kws)
 
     def frepo_qdii_secuportfolio(self, instruments, fields=None, **kws):
         """
