@@ -20,6 +20,7 @@ ashare_holdernumber = os.path.join(data_path,r'AShareHolderNumber')
 ashare_insideholder =  os.path.join(data_path,r'AShareInsideHolder')
 ashare_holderdata =  os.path.join(data_path,r'AShareinstHolderDerData')
 ashare_managerewr = os.path.join(data_path,r'AShareManagementHoldReward')
+ashare_dividend = os.path.join(data_path,r'AShareDividend')
 
 ashare_issuedate_pre = os.path.join(data_path,r'AShareIssuingDatePredict')
 ashare_fanc_indicator = os.path.join(data_path,r'AShareFinancialIndicator')
@@ -118,6 +119,10 @@ class LoacalFincReportsProvider(BaseFincReportsProvider):
     def repo_fanc_indicator(self,instruments,fields,**kws):
         return self.get_repo_data(ashare_fanc_indicator,instruments,fields,**kws)
 
+    @print_func_time
+    def repo_ashare_dividend(self,instruments,fields,**kws):
+        return self.get_repo_data(ashare_dividend,instruments,fields,**kws)
+
 class LoacalFundReportsProvider(BaseFincReportsProvider):
 
     def __init__(self, tidx=['ann_date','prt_enddate']) -> None:
